#!/bin/bash

# This script was designed to be used with Gentoo Studio, which has certain EMERGE_DEFAULT_OPTS set.
# Using it elsewhere could have unexpected results.

# Put in "press enter to continue" steps so user can read the echo outputs
# Also put in an arg so user can say "don't tell me, just do it."

echo "#################################################################"
echo "### Syncing with repositories. Please be patient.             ###"
echo "### Declining any part of this update will cancel the update. ###"
echo "### You may need to hit Enter twice if cancelling.            ###"
echo "#################################################################"
emaint sync -a
read userchoice
if [[ $userchoice != "y" ]]; then
	if [[ $userchoice != "Y" ]]; then
		echo "Update cancelled."
		exit 1
	fi
fi
eix-update

echo "##############################"
echo "### Updating system set... ###"
echo "##############################"
emerge --update --newuse --deep --backtrack=250 --keep-going @system
read userchoice
if [[ $userchoice != "y" ]]; then
        if [[ $userchoice != "Y" ]]; then
                echo "Update cancelled."
                exit 1
        fi
fi

echo "#############################"
echo "### Updating world set... ###"
echo "#############################"
emerge --update --newuse --deep --backtrack=250 --keep-going @world
read userchoice
if [[ $userchoice != "y" ]]; then
        if [[ $userchoice != "Y" ]]; then
                echo "Update cancelled."
                exit 1
        fi
fi

echo "##############################################"
echo "### Rebuilding preserved libs as needed... ###"
echo "##############################################"
emerge @preserved-rebuild

echo "###################################"
echo "### Rebuilding live packages... ###"
echo "###################################"
smart-live-rebuild

echo "###################################"
echo "### Removing unused packages... ###"
echo "###################################"
emerge --clean

echo "#######################################"
echo "### Removing unused dependencies... ###"
echo "#######################################"
emerge --depclean

echo "###########################################"
echo "### Rebuild any missing dependencies... ###"
echo "###########################################"
revdep-rebuild

echo "###########################################"
echo "### Updating configuration files...     ###"
echo "### update your configs by hitting 'u'  ###"
echo "### Unless you know what you're doing.  ###"
echo "###########################################"
dispatch-conf

echo "###########################################################"
echo "### Security issues (Gentoo Linux Security Advisories): ###"
echo "###########################################################"
glsa-check -t all
# Need handling to display more info about affected GLSAs and what to do about them.

echo "#######################################################"
echo "### Cleaning up... 			          ###"
echo "### Do you want to clear the distfiles cache? (y/n) ###"
echo "#######################################################"
read clearcachechoice
if [[ $clearcachechoice == "y" ]]; then
	rm -rv /var/cache/distfiles/*
elif [[ $clearcachechoice == "n" ]]; then
	echo "Not clearing distfiles cache."
else echo "Invalid choice, not clearing distfiles cache. To manually clear cache, run 'rm -r /var/cache/distfiles/*' as root."
fi

echo "#########################"
echo "### Updates complete. ###"
echo "#########################"
